#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-DbL9TpiJir031tT44i2jBo
key:                  postgrest-10.1.0-DbL9TpiJir031tT44i2jBo
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  c0fbc144ee20191e46dcce8ed4bb4b33
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-DbL9TpiJir031tT44i2jBo
depends:
    HTTP-4000.4.1-LkUOcgMBczeF8qgODB2fxV
    Ranged-sets-0.5.0-ENpCBwgwe9rKTpThjmqNOe
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU
    auto-update-0.1.6-2xkrFFEKLaCJXhNi6NXd2l base-4.18.2.1
    base64-bytestring-1.2.1.0-7JruMLJLgBF2cqlGBjJEVX
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-8beqaZQCG6YFLwD8uR7pTp
    cassava-0.5.4.1-3iTCOazhAZS2rwrvJ6RRHX
    configurator-pg-0.2.11-68ZgIyAYPjLWHho6XNQQB containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-4oon1pfjcei5YxwlRFwIb0
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-7k7GpLunpEBJuqmzGwWFgU
    hasql-dynamic-statements-0.3.1.2-3eyV6olEflZEUWIiDznfE8
    hasql-notifications-0.2.0.5-GUqKmxDCR25HK4cDCoHxTV
    hasql-pool-0.8.0.2-J98qrkCFmro8Wnp6v7oKlU
    hasql-transaction-1.0.1.2-Ht0wBM3Vy1zGK8FMHhqz6p
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9
    insert-ordered-containers-0.2.5.3-GWRWSzqIBYjL1SDONcn8jA
    interpolatedstring-perl6-1.0.2-GRKqBEpzA5r2imBu9zzjFV
    jose-0.10.0.1-7yuFnG0MStb584kZHlhQuK
    lens-5.3.4-4VhpdbpDp0x9CLN9dxQmc7
    lens-aeson-1.2.3-FqT8XoTlMtx6waVVY3vUkT mtl-2.3.1
    network-3.1.4.0-tP2o8Wry2b3nJpuPXPLoR
    network-uri-2.6.4.2-DXIr6FO81fkKKSx83uC4Cz
    optparse-applicative-0.18.1.0-7oEyKoVs7Vv7h3tuBTvFI7
    parsec-3.1.16.1 protolude-0.3.5-64QhnqRdGUl9cuiIUrTavE
    regex-tdfa-1.3.2.5-DSpNPpF3mjD6KIMmBJHiEZ
    retry-0.9.3.1-FiXUOeJkTzZLKJEWVHgT6
    scientific-0.3.8.1-25vWQKW70jDDFFn5H243Ra
    swagger2-2.8.10-HEtS8oErOJr4rHj2op4pZP text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3
    vault-0.3.1.6-9LEDSQf01dO8jjPC40E1mt
    vector-0.13.2.0-9FXioZw2Nye8eueJzIuHK4
    wai-3.2.4-56REQg4dhfjHKYLZyIkMb9
    wai-cors-0.2.7-3Wk3C2jinYf5MElKCwRRnt
    wai-extra-3.1.18-5k2W4LqYhoDGzXjcRflwkf
    wai-logger-2.5.0-HobqtCrrapi2qdHWbvl44W
    warp-3.4.0-Bz53tmaUOCu1sZfrie2t5U

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

